package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

/**
 * GitFileSource
 */
public class GitFileSource extends FileSource {
    @Nonnull private final String gitUrl;
    @Nullable private final String repoSubDir;
    @Nullable private final String branch;

    @Nullable private final String username;
    @Nullable private final String password;

    @Nullable private final String privateKeyPem;

    //name of the single file in the git repo we are interested in
    @Nullable private final String filename;

    public GitFileSource(@Nonnull  String gitUrl,
                         @Nullable String repoSubDir,
                         @Nullable String branch,
                         @Nullable String username,
                         @Nullable String password,
                         @Nullable String privateKeyPem,
                         @Nullable String filename) {
        super(SourceType.GIT, gitUrl, filename == null ? "git-repo" : filename);
        this.gitUrl = gitUrl;
        this.repoSubDir = repoSubDir;
        this.branch = branch;
        this.username = username;
        this.password = password;
        this.privateKeyPem = privateKeyPem;
        this.filename = filename;
    }

    @Nonnull
    public String getGitUrl() {
        return gitUrl;
    }

    @Nullable
    public String getRepoSubDir() {
        return repoSubDir;
    }

    @Nullable
    public String getBranch() {
        return branch;
    }

    @Nullable
    public String getUsername() {
        return username;
    }

    @Nullable
    public String getPassword() {
        return password;
    }

    @Nullable
    public String getPrivateKeyPem() {
        return privateKeyPem;
    }

    @Nullable
    public String getFilename() {
        return filename;
    }

    public boolean isFile() {
        return filename != null;
    }
    public boolean isDir() {
        return filename == null;
    }
}
